@@ -25,6 +25,7 @@ _defaultconf = {
     'define_builtin_instrs': True,
     'dynamic_pfields': True,
     'html_theme': 'light',
+    'html_repr_fontsize': '12px',
     'html_args_fontsize': '12px',
     'jupyter_synth_repr_stopbutton': True,
     'jupyter_synth_repr_interact': True,
@@ -49,7 +50,6 @@ _defaultconf = {
     'sched_latency': 0.05,
     'set_sigint_handler': True,
     'sr': 0,
-    'suppress_output': True,
     'synth_repr_max_args': 12,
     'synth_repr_show_pfield_index': False,
     'synthgroup_repr_max_rows': 4,
@@ -125,8 +125,6 @@ _docs = {
         'Set a sigint handler to prevent csound crash with CTRL-C',
     'disable_signals':
         'Disable atexit and sigint signal handler',
-    'suppress_output':
-        'Suppress csound´s debugging information',
     'unknown_parameter_fail_silently':
         'Do not raise if a synth tries to set an unknown parameter',
     'define_builtin_instrs':
