@@ -1,7 +1,11 @@
-class CsoundError(Exception): pass
+from __future__ import annotations
+
+
+class CsoundError(Exception):
+    pass
 
 class TableNotFoundError(CsoundError):
     "The table does not exist"
 
 
-class RenderError(Exception): ...
\ No newline at end of file
+class RenderError(Exception): ...
