@@ -10,15 +10,16 @@ from emlib import iterlib
 
 from . import csoundparse
 from . import instrtools
+from . import interact as _interact
 from ._common import EMPTYDICT, EMPTYSET
 from .config import config, logger
 from .errors import CsoundError
 
 from typing import TYPE_CHECKING
 if TYPE_CHECKING:
-    from typing import Callable, Sequence, Mapping
+    from typing import Callable, Sequence, Mapping, Any
     from .abstractrenderer import AbstractRenderer
-
+    from .synth import Synth
 
 __all__ = (
     'Instr',
@@ -52,6 +53,13 @@ class Instr:
         useDynamicPfields: if True, use pfields to implement dynamic arguments (arguments
             given as k-variables). Otherwise dynamic args are implemented as named controls,
             using a big global table
+        initCallback: function called whenever the instrument is instantiated for the first
+            time, at any priority. Signature: ``(renderer) -> None``, where renderer
+            is either a Session or an OfflineSession.
+        setCallback: a func of the form (Synth, param: str, value: float, delay: float) -> None,
+            will be called whenever a synth created from this instr calls its .set method.
+            The return value indicates if the event should actually proceed with
+            setting its parameter to the given value (False=bypass the operation)
 
     Example
     -------
@@ -199,6 +207,15 @@ class Instr:
         session.set(events[1], 3, 'kmidi', 67.2)
         session.render("out.wav")
 
+    **Init callback**
+
+    An Instr can declare an init callback to setup any resources needed
+
+    .. code-block:: python
+
+        from csoundengine import *
+        session = Session()
+        # TODO
     """
 
     __slots__ = (
@@ -206,7 +223,6 @@ class Instr:
         'pfields',
         'aliases',
         'init',
-        'id',
         'controls',
         'numchans',
         'doc',
@@ -217,12 +233,16 @@ class Instr:
         'includes',
         'parsedCode',
         'minPriority',
+        'properties',
+        'specs',
+        '_id',
         '_controlsDefaultValues',
         '_controlsNameToIndex',
         '_argToAlias',
         '_preprocessedBody',
         '_defaultPfieldValues',
-        '_initCallback'
+        '_initCallback',
+        '_setCallback'
     )
 
     def __init__(self,
@@ -238,6 +258,9 @@ class Instr:
                  useDynamicPfields: bool | None = None,
                  minPriority=1,
                  initCallback: Callable[[AbstractRenderer], None] | None = None,
+                 properties: dict[str, Any] = {},
+                 specs: Sequence[_interact.ParamSpec] | None = None,
+                 setCallback: Callable[[Synth, str, float, float], bool] | None = None,
                  ) -> None:
 
         assert isinstance(name, str)
@@ -339,9 +362,6 @@ class Instr:
         self.doc = doc
         "Description of this instr (optional)"
 
-        self.id: int = self._calculateHash()
-        "Unique numeric id of this instr"
-
         self.pfieldIndexToName: dict[int, str] = pargsIndexToName
         "Dict mapping pfield index to its name"
 
@@ -366,9 +386,31 @@ class Instr:
         be scheduled at the lowest priority, for example.
         """
 
+        self.properties = properties
+        """
+        A dict to hold properties set by the user
+        """
+
+        if specs is not None:
+            assert all(isinstance(spec, _interact.ParamSpec) for spec in specs), f"Invalid specs: {specs}"
+
+        self.specs: dict[str, _interact.ParamSpec] = {} if not specs else {s.name: s for s in specs}
+        """
+        A dict holding interact specs for the arguments of this instr
+        """
+
+        self._id: int = 0  # Used to hold the hash
         self._argToAlias = {name: alias for alias, name in aliases.items()} if aliases else EMPTYDICT
         self._defaultPfieldValues: list[float | str] = list(self.pfields.values())
         self._initCallback = initCallback
+        self._setCallback = setCallback
+
+    @property
+    def id(self) -> int:
+        "Unique numeric id of this instr"
+        if self._id == 0:
+            self._id = self._calculateHash()
+        return self._id
 
     def register(self, renderer: AbstractRenderer) -> None:
         """
@@ -396,8 +438,9 @@ class Instr:
     def _calculateHash(self) -> int:
         argshash = hash(frozenset(self.pfields.items())) if self.pfields else 0
         tabhash = hash(frozenset(self.controls.items())) if self.controls else 0
+        prophash = hash(frozenset(self.properties.items())) if self.properties else 0
         return hash((self.name, self.originalBody, self.init, self.doc, self.numchans,
-                     argshash, tabhash, self.includes))
+                     argshash, tabhash, prophash, self.includes))
 
     def __hash__(self) -> int:
         return self.id
